@@ -17,25 +17,25 @@
 #ifndef _K3BSETUP2_H_
 #define _K3BSETUP2_H_
 
-#include <kcmodule.h>
-#include <kaboutdata.h>
+#include <tdecmodule.h>
+#include <tdeaboutdata.h>
 
 
 class base_K3bSetup2;
 class TQCheckListItem;
 
 
-class K3bSetup2: public KCModule
+class K3bSetup2: public TDECModule
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bSetup2( TQWidget* parent = 0, const char* name = 0, const TQStringList& args = TQStringList() );
   ~K3bSetup2();
 
   TQString quickHelp() const;
-  const KAboutData* aboutData() { return m_aboutData; };
+  const TDEAboutData* aboutData() { return m_aboutData; };
 
   void load();
   void save();
@@ -60,7 +60,7 @@ class K3bSetup2: public KCModule
 
   base_K3bSetup2* w;
 
-  KAboutData* m_aboutData;
+  TDEAboutData* m_aboutData;
 };
 
 #endif
