@@ -32,7 +32,9 @@ class K3bCdrecordWriter;
 class K3bMsInfoFetcher;
 class K3bAudioNormalizeJob;
 class K3bAudioJobTempData;
-class K3bDevice::Device;
+namespace K3bDevice {
+    class Device;
+}
 
 /**
   *@author Sebastian Trueg
