@@ -29,9 +29,7 @@
 #include <dbus/connection.h>
 #include <dbus/dbus.h>
 #include <hal/libhal.h>
-#else // HAVE_HAL
-#include <tdehardwaredevices.h>
-#endif // HAVE_HAL
+#endif
 
 #ifdef HAVE_HAL
 static char** qstringListToArray( const TQStringList& s )
@@ -613,8 +611,29 @@ void K3bDevice::HalConnection::setupDBusTQtConnection( DBusConnection* dbusConne
   d->dBusTQtConnection->dbus_connection_setup_with_qt_main( dbusConnection );
 }
 
+void K3bDevice::HalConnection::AddDeviceHandler(TDEGenericDevice* hwdevice)
+{
+	// Empty body, only to avoid linking errors
+}
+
+void K3bDevice::HalConnection::RemoveDeviceHandler(TDEGenericDevice* hwdevice)
+{
+	// Empty body, only to avoid linking errors
+}
+
+void K3bDevice::HalConnection::ModifyDeviceHandler(TDEGenericDevice* hwdevice)
+{
+	// Empty body, only to avoid linking errors
+}
+
 #else // HAVE_HAL
 
+#ifdef __TDE_HAVE_TDEHWLIB
+#include <tdehardwaredevices.h>
+#else
+#define TDEHardwareDevices void
+#endif
+
 K3bDevice::HalConnection* K3bDevice::HalConnection::s_instance = 0;
 
 
@@ -674,6 +693,7 @@ bool K3bDevice::HalConnection::isConnected() const
 
 bool K3bDevice::HalConnection::open()
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	// Initialize the TDE device manager
 	d->m_hwdevices = TDEGlobal::hardwareDevices();
 
@@ -694,6 +714,9 @@ bool K3bDevice::HalConnection::open()
 	}
 	
 	return true;
+#else
+	return false;
+#endif
 }
 
 
@@ -710,6 +733,7 @@ TQStringList K3bDevice::HalConnection::devices() const
 
 void K3bDevice::HalConnection::AddDeviceHandler(TDEGenericDevice* hwdevice)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (hwdevice->type() != TDEGenericDeviceType::Disk) {
 		return;
 	}
@@ -730,10 +754,12 @@ void K3bDevice::HalConnection::AddDeviceHandler(TDEGenericDevice* hwdevice)
 			}
 		}
 	}
+#endif
 }
 
 void K3bDevice::HalConnection::RemoveDeviceHandler(TDEGenericDevice* hwdevice)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (hwdevice->type() != TDEGenericDeviceType::Disk) {
 		return;
 	}
@@ -752,10 +778,12 @@ void K3bDevice::HalConnection::RemoveDeviceHandler(TDEGenericDevice* hwdevice)
 			emit mediumChanged(blockDevice);
 		}
 	}
+#endif
 }
 
 void K3bDevice::HalConnection::ModifyDeviceHandler(TDEGenericDevice* hwdevice)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (hwdevice->type() != TDEGenericDeviceType::Disk) {
 		return;
 	}
@@ -767,11 +795,12 @@ void K3bDevice::HalConnection::ModifyDeviceHandler(TDEGenericDevice* hwdevice)
 		d->deviceMediumUdiMap[blockDevice] = sdevice->mediaInserted();
 		emit mediumChanged(blockDevice);
 	}
+#endif
 }
 
-
 int K3bDevice::HalConnection::lock(Device* dev)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (!d->deviceUdiMap.contains(dev->blockDeviceName())) {
 		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
 	}
@@ -792,11 +821,15 @@ int K3bDevice::HalConnection::lock(Device* dev)
 	else {
 		return org_freedesktop_Hal_Device_Volume_InvalidEjectOption;
 	}
+#else
+		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
+#endif
 }
 
 
 int K3bDevice::HalConnection::unlock(Device* dev)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (!d->deviceUdiMap.contains(dev->blockDeviceName())) {
 		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
 	}
@@ -817,6 +850,9 @@ int K3bDevice::HalConnection::unlock(Device* dev)
 	else {
 		return org_freedesktop_Hal_Device_Volume_InvalidEjectOption;
 	}
+#else
+		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
+#endif
 }
 
 
@@ -825,6 +861,7 @@ int K3bDevice::HalConnection::mount( K3bDevice::Device* dev,
 				     const TQString& fstype,
 				     const TQStringList& options )
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (!d->deviceUdiMap.contains(dev->blockDeviceName())) {
 		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
 	}
@@ -849,11 +886,15 @@ int K3bDevice::HalConnection::mount( K3bDevice::Device* dev,
 	else {
 		return org_freedesktop_Hal_Success;
 	}
+#else
+		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
+#endif
 }
 
 
 int K3bDevice::HalConnection::unmount(K3bDevice::Device* dev, const TQStringList& options)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (!d->deviceUdiMap.contains(dev->blockDeviceName())) {
 		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
 	}
@@ -879,11 +920,15 @@ int K3bDevice::HalConnection::unmount(K3bDevice::Device* dev, const TQStringList
 	else {
 		return org_freedesktop_Hal_Success;
 	}
+#else
+		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
+#endif
 }
 
 
 int K3bDevice::HalConnection::eject(K3bDevice::Device* dev, const TQStringList& options)
 {
+#ifdef __TDE_HAVE_TDEHWLIB
 	if (!d->deviceUdiMap.contains(dev->blockDeviceName())) {
 		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
 	}
@@ -904,6 +949,9 @@ int K3bDevice::HalConnection::eject(K3bDevice::Device* dev, const TQStringList&
 	else {
 		return org_freedesktop_Hal_Device_Volume_InvalidEjectOption;
 	}
+#else
+		return org_freedesktop_Hal_Device_Volume_NoSuchDevice;
+#endif
 }
 
 #endif // HAVE_HAL
