@@ -41,16 +41,16 @@
 #include <k3btrack.h>
 #include <k3bcdtext.h>
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kurlrequester.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kstdguiitem.h>
 #include <kguiitem.h>
 #include <kiconloader.h>
-#include <kconfig.h>
-#include <kio/global.h>
+#include <tdeconfig.h>
+#include <tdeio/global.h>
 #include <kurl.h>
 #include <kinputdialog.h>
 #include <kurldrag.h>
@@ -163,7 +163,7 @@ void K3bCdImageWritingDialog::init()
   if( !d->imageForced ) {
     // when opening the dialog first the default settings are loaded and afterwards we set the 
     // last written image because that's what most users want
-    KConfig* c = k3bcore->config();
+    TDEConfig* c = k3bcore->config();
     c->setGroup( configGroup() );
     TQString image = c->readPathEntry( "last written image" );
     if( TQFile::exists( image ) )
@@ -224,8 +224,8 @@ void K3bCdImageWritingDialog::setupGui()
   m_infoView->setFullWidth(true);
   m_infoView->setSelectionMode( TQListView::NoSelection );
 
-  connect( m_infoView, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),
-	   this, TQT_SLOT(slotContextMenu(KListView*, TQListViewItem*, const TQPoint&)) );
+  connect( m_infoView, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+	   this, TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)) );
 
 
   m_writerSelectionWidget = new K3bWriterSelectionWidget( frame );
@@ -252,7 +252,7 @@ void K3bCdImageWritingDialog::setupGui()
   groupCopies->setInsideSpacing( spacingHint() );
   groupCopies->setInsideMargin( marginHint() );
   TQLabel* pixLabel = new TQLabel( groupCopies );
-  pixLabel->setPixmap( SmallIcon( "cdcopy", KIcon::SizeMedium ) );
+  pixLabel->setPixmap( SmallIcon( "cdcopy", TDEIcon::SizeMedium ) );
   pixLabel->setScaledContents( false );
   m_spinCopies = new TQSpinBox( groupCopies );
   m_spinCopies->setMinValue( 1 );
@@ -337,7 +337,7 @@ void K3bCdImageWritingDialog::slotStartClicked()
   d->md5Job->cancel();
 
   // save the path
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup( configGroup() );
   c->writePathEntry( "last written image", imagePath() );
 
@@ -404,7 +404,7 @@ void K3bCdImageWritingDialog::slotStartClicked()
     {
       K3bIso9660 isoFs( d->imageFile );
       if( isoFs.open() ) {
-	if( K3b::filesize( KURL::fromPathOrURL(d->imageFile) ) < (KIO::filesize_t)(isoFs.primaryDescriptor().volumeSpaceSize*2048) ) {
+	if( K3b::filesize( KURL::fromPathOrURL(d->imageFile) ) < (TDEIO::filesize_t)(isoFs.primaryDescriptor().volumeSpaceSize*2048) ) {
 	  if( KMessageBox::questionYesNo( this, 
 					  i18n("<p>This image has an invalid file size."
 					       "If it has been downloaded make sure the download is complete."
@@ -447,7 +447,7 @@ void K3bCdImageWritingDialog::slotStartClicked()
     
     delete job;
 
-    if( KConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "keep action dialogs open", false ) &&
+    if( TDEConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "keep action dialogs open", false ) &&
 	!exitLoopOnHide() )
       show();
     else
@@ -569,14 +569,14 @@ void K3bCdImageWritingDialog::slotUpdateImage( const TQString& )
       K3bListViewItem* item = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						   i18n("Seems not to be a usable image") );
       item->setForegroundColor( 0, TQt::red );
-      item->setPixmap( 0, SmallIcon( "stop") );
+      item->setPixmap( 0, SmallIcon( "process-stop") );
     }
   }
   else {
     K3bListViewItem* item = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						 i18n("File not found") );
     item->setForegroundColor( 0, TQt::red );
-    item->setPixmap( 0, SmallIcon( "stop") );
+    item->setPixmap( 0, SmallIcon( "process-stop") );
   }
 
   slotToggleAll();
@@ -589,12 +589,12 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 						      i18n("Detected:"),
 						      i18n("Iso9660 image") );
   isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
-  isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
+  isoRootItem->setPixmap( 0, SmallIcon( "application-x-cd-image") );
 
-  KIO::filesize_t size = K3b::filesize( KURL::fromPathOrURL(isoF->fileName()) );
+  TDEIO::filesize_t size = K3b::filesize( KURL::fromPathOrURL(isoF->fileName()) );
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
 					       i18n("Filesize:"), 
-					       KIO::convertSize( size ) );
+					       TDEIO::convertSize( size ) );
   item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
@@ -654,10 +654,10 @@ void K3bCdImageWritingDialog::createCdrecordCloneItems( const TQString& tocFile,
 						      i18n("Detected:"),
 						      i18n("Cdrecord clone image") );
   isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
-  isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
+  isoRootItem->setPixmap( 0, SmallIcon( "application-x-cd-image") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
-					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
+					       i18n("Filesize:"), TDEIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
   item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
@@ -682,10 +682,10 @@ void K3bCdImageWritingDialog::createCueBinItems( const TQString& cueFile, const
 						      i18n("Detected:"),
 						      i18n("Cue/bin image") );
   isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
-  isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
+  isoRootItem->setPixmap( 0, SmallIcon( "application-x-cd-image") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
-					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
+					       i18n("Filesize:"), TDEIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
   item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
@@ -710,7 +710,7 @@ void K3bCdImageWritingDialog::createAudioCueItems( const K3bCueFileParser& cp )
 						   i18n("Detected:"),
 						   i18n("Audio Cue Image") );
   rootItem->setForegroundColor( 0, palette().disabled().foreground() );
-  rootItem->setPixmap( 0, SmallIcon( "sound") );
+  rootItem->setPixmap( 0, SmallIcon( "audio-x-generic") );
 
   K3bListViewItem* trackParent = new K3bListViewItem( rootItem,
 						      i18n("%n track", "%n tracks", cp.toc().count() ),
@@ -841,7 +841,7 @@ void K3bCdImageWritingDialog::calculateMd5Sum( const TQString& file )
   d->md5SumItem->setText( 0, i18n("Md5 Sum:") );
   d->md5SumItem->setForegroundColor( 0, palette().disabled().foreground() );
   d->md5SumItem->setProgress( 1, 0 );
-  d->md5SumItem->setPixmap( 0, SmallIcon( "exec") );
+  d->md5SumItem->setPixmap( 0, SmallIcon( "application-x-executable") );
 
   if( file != d->lastCheckedFile ) {
     d->lastCheckedFile = file;
@@ -871,7 +871,7 @@ void K3bCdImageWritingDialog::slotMd5JobFinished( bool success )
       d->md5SumItem->setText( 1, i18n("Calculation cancelled") );
     else
       d->md5SumItem->setText( 1, i18n("Calculation failed") );
-    d->md5SumItem->setPixmap( 0, SmallIcon( "stop") );
+    d->md5SumItem->setPixmap( 0, SmallIcon( "process-stop") );
     d->lastCheckedFile.truncate(0);
   }
 
@@ -879,7 +879,7 @@ void K3bCdImageWritingDialog::slotMd5JobFinished( bool success )
 }
 
 
-void K3bCdImageWritingDialog::slotContextMenu( KListView*, TQListViewItem*, const TQPoint& pos )
+void K3bCdImageWritingDialog::slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint& pos )
 {
   if( !d->haveMd5Sum )
     return;
@@ -912,7 +912,7 @@ void K3bCdImageWritingDialog::slotContextMenu( KListView*, TQListViewItem*, cons
 }
 
 
-void K3bCdImageWritingDialog::loadUserDefaults( KConfigBase* c )
+void K3bCdImageWritingDialog::loadUserDefaults( TDEConfigBase* c )
 {
   m_writingModeWidget->loadConfig( c );
   m_checkDummy->setChecked( c->readBoolEntry("simulate", false ) );
@@ -954,7 +954,7 @@ void K3bCdImageWritingDialog::loadUserDefaults( KConfigBase* c )
 }
 
 
-void K3bCdImageWritingDialog::saveUserDefaults( KConfigBase* c )
+void K3bCdImageWritingDialog::saveUserDefaults( TDEConfigBase* c )
 {
   m_writingModeWidget->saveConfig( c ),
   c->writeEntry( "simulate", m_checkDummy->isChecked() );
