@@ -29,7 +29,7 @@ namespace K3bDevice {
 class K3bDvdFormattingDialog : public K3bInteractionDialog
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bDvdFormattingDialog( TQWidget* = 0, const char* = 0, bool modal = true );
@@ -43,8 +43,8 @@ class K3bDvdFormattingDialog : public K3bInteractionDialog
   void slotWriterChanged();
 
  private:
-  void loadUserDefaults( KConfigBase* );
-  void saveUserDefaults( KConfigBase* );
+  void loadUserDefaults( TDEConfigBase* );
+  void saveUserDefaults( TDEConfigBase* );
   void loadK3bDefaults();
 
   K3bWriterSelectionWidget* m_writerSelectionWidget;
