@@ -29,7 +29,7 @@ class TQCheckBox;
 class K3bMovixDvdBurnDialog : public K3bProjectBurnDialog
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bMovixDvdBurnDialog( K3bMovixDvdDoc* doc, TQWidget* parent = 0, const char* name = 0, bool modal = true );
@@ -42,8 +42,8 @@ class K3bMovixDvdBurnDialog : public K3bProjectBurnDialog
   void saveSettings();
   void readSettings();
   void loadK3bDefaults();
-  void loadUserDefaults( KConfigBase* );
-  void saveUserDefaults( KConfigBase* );
+  void loadUserDefaults( TDEConfigBase* );
+  void saveUserDefaults( TDEConfigBase* );
   void toggleAll();
 
  private:
