@@ -21,13 +21,13 @@
 class K3bProjectPlugin;
 class K3bProjectPluginGUIBase;
 class K3bDoc;
-class KConfigBase;
+class TDEConfigBase;
 
 
 class K3bProjectPluginDialog : public K3bInteractionDialog
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bProjectPluginDialog( K3bProjectPlugin*, K3bDoc*, TQWidget*, const char* name = 0 );
@@ -35,8 +35,8 @@ class K3bProjectPluginDialog : public K3bInteractionDialog
   
  protected slots:
   void slotStartClicked();
-  void saveUserDefaults( KConfigBase* config );
-  void loadUserDefaults( KConfigBase* config );
+  void saveUserDefaults( TDEConfigBase* config );
+  void loadUserDefaults( TDEConfigBase* config );
   void loadK3bDefaults();
 
  private:
