@@ -28,7 +28,7 @@ class TQCheckBox;
 class K3bVideoDvdBurnDialog : public K3bProjectBurnDialog
 {
  Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
    K3bVideoDvdBurnDialog( K3bVideoDvdDoc*, TQWidget *parent = 0, const char *name = 0, bool modal = true );
@@ -41,8 +41,8 @@ class K3bVideoDvdBurnDialog : public K3bProjectBurnDialog
 
  protected:
    void loadK3bDefaults();
-   void loadUserDefaults( KConfigBase* );
-   void saveUserDefaults( KConfigBase* );
+   void loadUserDefaults( TDEConfigBase* );
+   void saveUserDefaults( TDEConfigBase* );
    void toggleAll();
 
  private:
